# Release Notes

## 4.18.0
**New Features**

* Added `AlertManager.configureSymbolLookup` to allow symbol validation, based on the user's domain.

## 4.17.0
**New Features**

* Added `AlertManager.deletePublisherTypeDefault` function.

**Bug Fixes**

* Corrected validation logic for `PublisherTypeDefault` object creation.

**Other**

* Fixed failure of example page to properly update UI state after saving publisher settings.

## 4.16.0
**New Features**

* Added the `AlertManager.subscribeConnectionStatus` function.

**Technical Enhancements**

* Updated logic that invokes consumer-provided subscription handler functions to `catch` any uncaught errors generated by the handlers and continue operations.

## 4.15.0
**New Features**

* Added a static, undocumented function called `AlertsManager.filterPropertiesForSymbol` which determines which properties are valid for a given symbol.
* Added a static, undocumented function called `AlertsManager.filterTemplatesForSymbol` which determines which templates are valid for a given symbol.

## 4.14.0
**New Features**

* Updated the `AlertManager.checkSymbol` function to reject equity option symbols.
* Updated the `AlertManager.createAlert` function to prevent creation of an alert that targets an equity option.
* Updated the `AlertManager.createAlert` function to prevent creation of an alert that targets a futures option, which evaluates anything other than a price (or volume) property.

## 4.13.0
**New Features**

* Added support for `title` attribute on publisher objects.



## 4.12.3
**Bug Fixes**

* Improved messaging of rejected promise from `AlertManager.createAlert` when attempting to create a condition using an invalid target symbol.

## 4.12.2
**Other**

* Updated documentation to describe mechanisms for retrieving a snapshot of the current user's alerts.
* No functional changes.

## 4.12.1
**Other**

* Added documentation for starting/stopping multiple alerts to "Quick Start" section.
* Fixed JavaScript "lint" in example code.
* No functional changes.

## 4.12.0
**New Features**

* Added the `AlertManager.subscribeTemplates` function.

## 4.10.0
**New Features**

* Modified the `Template` schema, adding an optional `frequency` property.

## 4.9.0
**New Features**

* Modified the `Alert` schema, adding an optional `template_id` property. This allows an alert to reference the template it was created from.
* Modified the `AlertManager.createAlertFromTemplate` function to assign the `template_id` property to the resulting Alert object.

## 4.8.0
**New Features**

* Added the `AlertManager.updateTemplateOrder` function.

## 4.7.0
**New Features**

* Added the `AlertManager.updateTemplate` function.

## 4.5.0
**New Features**

* Added "template" entities. Templates are used to define conditions (e.g. last price > $100) without reference to a specific target (e.g. Apple stock). Templates are intended to streamline user input (when multiple, similar alerts need to be created). To support these templates, three new functions were added — `AlertManager.retrieveTemplates`, `AlertManager.createTemplate`, `AlertManager.deleteTemplate`.
* Added a utility function, called `AlertManager.createAlertFromTemplate` to "merge" templates with targets (i.e. symbols), yielding an `Schema.Alert` object that can be saved.

## 4.4.0
**New Features**

* Added the `AlertBuilder` class, which provides a mechanism for generate schema-compliant JavaScript objects.
* Added `AlertManager.forStaging` function.
* Added `AlertManager.forProduction` function.


## 4.3.0
**Technical Enhancements**

* Upgraded the [@barchart/common-js](https://github.com/barchart/common-js) library to the next major version.
* Swapped the timeout mechanism for promises used by the `AlertManager` class.


## 4.2.0
**New Features**

* Added support for additional JSON data which can be included in alert trigger history. For example, the alert trigger item for news alerts will now include a link to the news article itself.

**Other**

* Updated OpenAPI file.

## 4.1.1
**Other**

* The [documentation site](https://docs.barchart.com/alerts/#/) is now complete.

## 4.1.0
**New Features**

* Publishing alerts via mobile push notification is now supported.
* Each time an alert is triggered, a persistent ```Trigger``` object is created.
* Queries for ```Trigger``` objects are now supported.
* Subscriptions to ```Trigger``` creation, mutation, and deletion are now supported.
* The status of a ```Trigger``` can be set to _Read_ or _Unread_.

**Technical Enhancements**

* The `JwtPayload.forSigning` function now emits an object which uses standard Barchart properties (i.e. `userId` instead of `user_id` and `contextId` instead of `alert_system`).
* The `getJwtGenrator` function no longer signs tokens. Instead, it delegates token signing to a web service.
* The `refreshInterval` parameter of the `JwtProvider` constructor is now optional.
* The `JwtProvider` now applies some jitter to the `refreshInterval` parameter.
* Added `.npmrc` file to reduce the clutter contained in a published NPM package.

**Other**

* The [documentation site](https://docs.barchart.com/alerts/#/) has been expanded, clarified, and improved.



## 4.0.6
**No functional changes**

* The ```package-lock.json``` file was removed and an ```.nmprc``` file was added. Dependency locking should be managed by the SDK consumer.
* The documentation was updated (specifically, the Security section).

## 4.0.1
**Initial Public Release**

* **Visibility**
  * GitHub repository's access level changed to public.
  * Published to NPM as a [public package](https://www.npmjs.com/package/@barchart/alerts-client-js).
  * MIT License applied.
* **Documentation**
  * [JSDoc](https://jsdoc.app/) completed and updated in code files.
  * [OpenAPI](https://www.openapis.org/) definition added.
  * Documentation site [published to GitHub Pages](https://barchart.github.io/alerts-client-js/).
* **Breaking Changes**
  * All environments now require JSON Web Tokens (JWT) for authentication and authorization.
  * The ```JwtProvider``` class has been refactored and moved.
  * The ```AlertManager``` constructor now requires an ```AdapterBase``` (specifies HTTP or WebSocket).

